import uuid
from django.core.management.base import BaseCommand
from rlhf.models import FeedbackTag
from django.utils import timezone


class Command(BaseCommand):
    help = '初始化反馈标签'

    def handle(self, *args, **options):
        # 正面标签
        positive_tags = [
            ('有帮助', '回答对问题有实际帮助'),
            ('准确', '信息准确可靠'),
            ('清晰', '表达清楚易懂'),
            ('完整', '回答全面完整'),
            ('友好', '语调友善亲切'),
            ('创新', '提供了新颖的观点')
        ]

        # 负面标签
        negative_tags = [
            ('不准确', '包含错误信息'),
            ('不相关', '回答偏离主题'),
            ('不完整', '回答过于简略'),
            ('不清晰', '表达模糊难懂'),
            ('不友好', '语调生硬冷淡'),
            ('重复', '内容重复冗余')
        ]

        # 插入正面标签
        for tag_name, description in positive_tags:
            FeedbackTag.objects.get_or_create(
                tag_name=tag_name,
                defaults={
                    'id': str(uuid.uuid4()),
                    'tag_type': 'positive',
                    'description': description,
                    'created_at': timezone.now()
                }
            )

        # 插入负面标签
        for tag_name, description in negative_tags:
            FeedbackTag.objects.get_or_create(
                tag_name=tag_name,
                defaults={
                    'id': str(uuid.uuid4()),
                    'tag_type': 'negative',
                    'description': description,
                    'created_at': timezone.now()
                }
            )

        self.stdout.write(self.style.SUCCESS('✅ 反馈标签已添加')) 